package
Version:
v0.12.2
Opens a new window with list of versions in this module.
Published: Nov 17, 2025
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type CLI struct {
Debug bool `name:"debug" short:"d" help:"enable debug view"`
RawLogs bool `name:"raw" short:"r" help:"disable prettified logs"`
NonInteractive bool `name:"non-interactive" short:"n" help:"disable interactive mode"`
Version bool `name:"version" short:"v" help:"print version"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.