sift

package
v0.12.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 17, 2025 License: MIT Imports: 21 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	CenterDotPulse = spinner.Spinner{
		Frames: []string{
			lipgloss.NewStyle().Foreground(lipgloss.AdaptiveColor{Light: "#808080", Dark: "#4D4D4D"}).Render("∙"),
			lipgloss.NewStyle().Foreground(lipgloss.AdaptiveColor{Light: "#A65D30", Dark: "#806040"}).Render("∙"),
			lipgloss.NewStyle().Foreground(lipgloss.AdaptiveColor{Light: "#C97009", Dark: "#B38030"}).Render("∙"),
			lipgloss.NewStyle().Foreground(lipgloss.AdaptiveColor{Light: "#D97009", Dark: "#FFAF00"}).Render("∙"),
			lipgloss.NewStyle().Foreground(lipgloss.AdaptiveColor{Light: "#C97009", Dark: "#B38030"}).Render("∙"),
			lipgloss.NewStyle().Foreground(lipgloss.AdaptiveColor{Light: "#A65D30", Dark: "#806040"}).Render("∙"),
		},
		FPS: time.Second / 10,
	}
)
var Version = "v0.12.2"

Functions

func FrameTicker added in v0.12.2

func FrameTicker(ctx context.Context, program *tea.Program, tps int)

sends a msg to bubbletea model on an interval to ensure the view is being updated according to framerate

func IsStdinTerminal added in v0.12.2

func IsStdinTerminal() bool

IsStdinTerminal checks if stdin is a terminal (no piped input)

func NewSiftModel

func NewSiftModel(opts SiftModelOptions) (*siftModel, error)

func Run

func Run(ctx context.Context, opts ProgramOptions) error

Types

type FrameMsg added in v0.2.0

type FrameMsg struct{}

type ProgramOptions added in v0.12.2

type ProgramOptions struct {
	Debug          bool
	NonInteractive bool
	PrettifyLogs   bool
}

type SiftModelOptions added in v0.12.2

type SiftModelOptions struct {
	ProgramOptions
	TestManager *tests.TestManager
}

Jump to